@@ -1,6 +1,6 @@
 
 #
-# Copyright (c) 2013, MasterCard International Incorporated
+# Copyright (c) 2013, 2014 MasterCard International Incorporated
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without modification, are 
@@ -868,17 +868,17 @@ class CardToken(Domain):
           Creates an CardToken object
           @param params: a dict of parameters; valid keys are:
               - C{callback}:  The URL callback for the cardtoken 
-              - C{card => addressCity}:  City of the cardholder. 
-              - C{card => addressCountry}:  Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. 
-              - C{card => addressLine1}:  Address of the cardholder. 
-              - C{card => addressLine2}:  Address of the cardholder if needed. 
-              - C{card => addressState}:  State code (USPS code) of residence of the cardholder. 
-              - C{card => addressZip}:  Postal code of the cardholder. 
+              - C{card => addressCity}:  City of the cardholder. [max length: 50, min length: 2] 
+              - C{card => addressCountry}:  Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. [max length: 2, min length: 2] 
+              - C{card => addressLine1}:  Address of the cardholder. [max length: 255] 
+              - C{card => addressLine2}:  Address of the cardholder if needed. [max length: 255] 
+              - C{card => addressState}:  State code (USPS code) of residence of the cardholder. [max length: 2, min length: 2] 
+              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers. [max length: 9, min length: 3] 
               - C{card => cvc}:  CVC security code of the card. This is the code on the back of the card. Example: 123 
-              - C{card => expMonth}:  Expiration month of the card. Format is MM. Example: January = 01 B{required }
-              - C{card => expYear}:  Expiration year of the card. Format is YY. Example: 2013 = 13 B{required }
-              - C{card => name}:  Name as appears on the card. 
-              - C{card => number}:  Card number as it appears on the card. B{required }
+              - C{card => expMonth}:  Expiration month of the card. Format is MM. Example: January = 01 [min value: 1, max value: 12] B{required }
+              - C{card => expYear}:  Expiration year of the card. Format is YY. Example: 2013 = 13 [max value: 99] B{required }
+              - C{card => name}:  Name as appears on the card. [max length: 50, min length: 2] 
+              - C{card => number}:  Card number as it appears on the card. [max length: 19, min length: 13] B{required }
               - C{key}:  Key used to create the card token. 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -910,8 +910,8 @@ class Chargeback(Domain):
           Retrieve Chargeback objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{id} C{amount} C{description} C{dateCreated}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -942,13 +942,13 @@ class Coupon(Domain):
         """
           Creates an Coupon object
           @param params: a dict of parameters; valid keys are:
-              - C{amountOff}:  Amount off of the price of the product in minor units in the currency of the merchant. While this field is optional, you must provide either amountOff or percentOff for a coupon. Example: 1000 = 10.00 
-              - C{couponCode}:  Code that identifies the coupon to be used. B{required }
+              - C{amountOff}:  Amount off of the price of the product in minor units in the currency of the merchant. While this field is optional, you must provide either amountOff or percentOff for a coupon. Example: 1000 = 10.00 [min value: 1, max value: 99999999] 
+              - C{couponCode}:  Code that identifies the coupon to be used. [min length: 2] B{required }
               - C{description}:  A brief section that describes the coupon. 
-              - C{durationInMonths}:  Duration in months that the coupon will be applied after it has first been selected. 
+              - C{durationInMonths}:  Duration in months that the coupon will be applied after it has first been selected. [min value: 1, max value: 9999] 
               - C{endDate}:  Last date of the coupon in UTC millis that the coupon can be applied to a subscription. This ends at 23:59:59 of the merchant timezone. 
-              - C{maxRedemptions}:  Maximum number of redemptions allowed for the coupon. A redemption is defined as when the coupon is applied to the subscription for the first time. 
-              - C{percentOff}:  Percentage off of the price of the product. While this field is optional, you must provide either amountOff or percentOff for a coupon. The percent off is a whole number. 
+              - C{maxRedemptions}:  Maximum number of redemptions allowed for the coupon. A redemption is defined as when the coupon is applied to the subscription for the first time. [min value: 1] 
+              - C{percentOff}:  Percentage off of the price of the product. While this field is optional, you must provide either amountOff or percentOff for a coupon. The percent off is a whole number. [min value: 1, max value: 100] 
               - C{startDate}:  First date of the coupon in UTC millis that the coupon can be applied to a subscription. This starts at midnight of the merchant timezone. B{required }
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -971,8 +971,8 @@ class Coupon(Domain):
           Retrieve Coupon objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{dateCreated} C{maxRedemptions} C{timesRedeemed} C{id} C{startDate} C{endDate} C{percentOff} C{couponCode} C{durationInMonths} C{amountOff}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -999,7 +999,7 @@ class Coupon(Domain):
           The properties that can be updated:  
             - C{endDate} The ending date in UTC millis for the coupon. This must be after the starting date of the coupon. 
 
-            - C{maxRedemptions} Maximum number of redemptions allowed for the coupon. A redemption is defined as when the coupon is applied to the subscription for the first time. 
+            - C{maxRedemptions} Maximum number of redemptions allowed for the coupon. A redemption is defined as when the coupon is applied to the subscription for the first time. [min value: 1] 
 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1018,28 +1018,29 @@ class Customer(Domain):
         """
           Creates an Customer object
           @param params: a dict of parameters; valid keys are:
-              - C{card => addressCity}:  City of the cardholder. 
-              - C{card => addressCountry}:  Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. 
-              - C{card => addressLine1}:  Address of the cardholder 
-              - C{card => addressLine2}:  Address of the cardholder if needed. 
-              - C{card => addressState}:  State code (USPS code) of residence of the cardholder. 
-              - C{card => addressZip}:  Postal code of the cardholder. 
-              - C{card => cvc}:  CVC security code of the card. This is the code on the back of the card. Example: 123 
+              - C{card => addressCity}:  City of the cardholder. B{required }
+              - C{card => addressCountry}:  Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. B{required }
+              - C{card => addressLine1}:  Address of the cardholder B{required }
+              - C{card => addressLine2}:  Address of the cardholder if needed. B{required }
+              - C{card => addressState}:  State code (USPS code) of residence of the cardholder. B{required }
+              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers. B{required }
+              - C{card => cvc}:  CVC security code of the card. This is the code on the back of the card. Example: 123 B{required }
               - C{card => expMonth}:  Expiration month of the card. Format is MM. Example: January = 01 B{required }
               - C{card => expYear}:  Expiration year of the card. Format is YY. Example: 2013 = 13 B{required }
-              - C{card => name}:  Name as appears on the card. 
-              - C{card => number}:  Card number as it appears on the card. B{required }
+              - C{card => id}:  ID of card. Unused during customer create. 
+              - C{card => name}:  Name as appears on the card. B{required }
+              - C{card => number}:  Card number as it appears on the card. [max length: 19, min length: 13] 
               - C{email}:  Email address of the customer B{required }
-              - C{name}:  Customer name B{required }
+              - C{name}:  Customer name [min length: 2] B{required }
               - C{reference}:  Reference field for external applications use. 
-              - C{subscriptions => amount}:  Amount of payment in minor units. Example: 1000 = 10.00 
+              - C{subscriptions => amount}:  Amount of payment in minor units. Example: 1000 = 10.00 [min value: 50, max value: 99999999] 
               - C{subscriptions => coupon}:  Coupon associated with the subscription for the customer. 
-              - C{subscriptions => currency}:  Currency code (ISO-4217). Must match the currency associated with your account. B{default:USD}
+              - C{subscriptions => currency}:  Currency code (ISO-4217). Must match the currency associated with your account. [default: USD] 
               - C{subscriptions => customer}:  The customer ID to create the subscription for. Do not supply this when creating a customer. 
               - C{subscriptions => frequency}:  Frequency of payment for the plan. Example: Monthly 
               - C{subscriptions => name}:  Name describing subscription 
               - C{subscriptions => plan}:  The plan ID that the subscription should be created from. 
-              - C{subscriptions => quantity}:  Quantity of the plan for the subscription. 
+              - C{subscriptions => quantity}:  Quantity of the plan for the subscription. [min value: 1] 
               - C{token}:  If specified, card associated with card token will be used 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1062,8 +1063,8 @@ class Customer(Domain):
           Retrieve Customer objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{dateCreated} C{id} C{name} C{email} C{reference}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1088,34 +1089,38 @@ class Customer(Domain):
           Updates this object
 
           The properties that can be updated:  
-            - C{card => addressCity} City of the cardholder. 
+            - C{card => addressCity} City of the cardholder. B{(required)}
 
-            - C{card => addressCountry} Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. 
+            - C{card => addressCountry} Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. B{(required)}
 
-            - C{card => addressLine1} Address of the cardholder. 
+            - C{card => addressLine1} Address of the cardholder. B{(required)}
 
-            - C{card => addressLine2} Address of the cardholder if needed. 
+            - C{card => addressLine2} Address of the cardholder if needed. B{(required)}
 
-            - C{card => addressState} State code (USPS code) of residence of the cardholder. 
+            - C{card => addressState} State code (USPS code) of residence of the cardholder. B{(required)}
 
-            - C{card => addressZip} Postal code of the cardholder. 
+            - C{card => addressZip} Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers. B{(required)}
 
-            - C{card => cvc} CVC security code of the card. This is the code on the back of the card. Example: 123 
+            - C{card => cvc} CVC security code of the card. This is the code on the back of the card. Example: 123 B{(required)}
 
             - C{card => expMonth} Expiration month of the card. Format is MM.  Example: January = 01 B{(required)}
 
             - C{card => expYear} Expiration year of the card. Format is YY. Example: 2013 = 13 B{(required)}
 
-            - C{card => name} Name as appears on the card. 
+            - C{card => id} ID of card. If present, card details for the customer will not be updated. If not present, the customer will be updated with the supplied card details. 
 
-            - C{card => number} Card number as it appears on the card. B{(required)}
+            - C{card => name} Name as appears on the card. B{(required)}
+
+            - C{card => number} Card number as it appears on the card. [max length: 19, min length: 13] 
 
             - C{email} Email address of the customer B{(required)}
 
-            - C{name} Customer name B{(required)}
+            - C{name} Customer name [min length: 2] B{(required)}
 
             - C{reference} Reference field for external applications use. 
 
+            - C{token} If specified, card associated with card token will be added to the customer 
+
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
           @return: a Customer object.
@@ -1134,8 +1139,8 @@ class Deposit(Domain):
           Retrieve Deposit objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{amount} C{dateCreated} C{depositDate}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1167,8 +1172,8 @@ class Invoice(Domain):
           Retrieve Invoice objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{id} C{invoiceDate} C{customer} C{amount} C{processedDate}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1193,7 +1198,7 @@ class Invoice(Domain):
           Updates this object
 
           The properties that can be updated:  
-            - C{status} Status of the invoice. Examples: OPEN = Invoice has not been processed and can have invoice items added to it. PAID = Invoice has been paid. UNPAID = Invoice was not paid when the card was processed. System will try up to 5 times to process the card. B{(required)}
+            - C{status} New status of the invoice. [valid values: PAID] B{(required)}
 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1212,8 +1217,8 @@ class InvoiceItem(Domain):
         """
           Creates an InvoiceItem object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of the invoice item (minor units). Example: 1000 = 10.00 B{required }
-              - C{currency}:  Currency code (ISO-4217) for the invoice item. Must match the currency associated with your account. B{required }B{default:USD}
+              - C{amount}:  Amount of the invoice item (minor units). Example: 1000 = 10.00 [min value: 1, max value: 99999999] B{required }
+              - C{currency}:  Currency code (ISO-4217) for the invoice item. Must match the currency associated with your account. [default: USD] B{required }
               - C{description}:  Individual items of an invoice 
               - C{invoice}:  Description of the invoice item B{required }
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
@@ -1237,8 +1242,8 @@ class InvoiceItem(Domain):
           Retrieve InvoiceItem objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{id} C{amount} C{description} C{invoice}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1263,9 +1268,9 @@ class InvoiceItem(Domain):
           Updates this object
 
           The properties that can be updated:  
-            - C{amount} Amount of the invoice item (minor units). Example: 1000 = 10.00 
+            - C{amount} Amount of the invoice item (minor units). Example: 1000 = 10.00 [min value: 1, max value: 99999999] 
 
-            - C{currency} Currency code (ISO-4217) for the invoice item. Must match the currency associated with your account. 
+            - C{currency} Currency code (ISO-4217) for the invoice item. Must match the currency associated with your account. [default: USD] 
 
             - C{description} Individual items of an invoice 
 
@@ -1286,23 +1291,23 @@ class Payment(Domain):
         """
           Creates an Payment object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of the payment (minor units). Example: 1000 = 10.00 B{required }
-              - C{card => addressCity}:  City of the cardholder. 
-              - C{card => addressCountry}:  Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. 
-              - C{card => addressLine1}:  Address of the cardholder. 
-              - C{card => addressLine2}:  Address of the cardholder if needed. 
-              - C{card => addressState}:  State code (USPS code) of residence of the cardholder. 
-              - C{card => addressZip}:  Postal code of the cardholder. 
+              - C{amount}:  Amount of the payment (minor units). Example: 1000 = 10.00 [min value: 50, max value: 99999999] B{required }
+              - C{card => addressCity}:  City of the cardholder. [max length: 50, min length: 2] 
+              - C{card => addressCountry}:  Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. [max length: 2, min length: 2] 
+              - C{card => addressLine1}:  Address of the cardholder. [max length: 255] 
+              - C{card => addressLine2}:  Address of the cardholder if needed. [max length: 255] 
+              - C{card => addressState}:  State code (USPS code) of residence of the cardholder. [max length: 2, min length: 2] 
+              - C{card => addressZip}:  Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers. [max length: 9, min length: 3] 
               - C{card => cvc}:  CVC security code of the card. This is the code on the back of the card. Example: 123 
-              - C{card => expMonth}:  Expiration month of the card. Format is MM. Example: January = 01 B{required }
-              - C{card => expYear}:  Expiration year of the card. Format is YY. Example: 2013 = 13 B{required }
-              - C{card => name}:  Name as it appears on the card. 
-              - C{card => number}:  Card number as it appears on the card. B{required }
-              - C{currency}:  Currency code (ISO-4217) for the transaction. Must match the currency associated with your account. B{required }B{default:USD}
+              - C{card => expMonth}:  Expiration month of the card. Format is MM. Example: January = 01 [min value: 1, max value: 12] B{required }
+              - C{card => expYear}:  Expiration year of the card. Format is YY. Example: 2013 = 13 [max value: 99] B{required }
+              - C{card => name}:  Name as it appears on the card. [max length: 50, min length: 2] 
+              - C{card => number}:  Card number as it appears on the card. [max length: 19, min length: 13] B{required }
+              - C{currency}:  Currency code (ISO-4217) for the transaction. Must match the currency associated with your account. [default: USD] B{required }
               - C{customer}:  ID of customer. If specified, card on file of customer will be used. 
               - C{description}:  Custom naming of payment for external systems to use. 
               - C{reference}:  Custom reference field to be used with outside systems. 
-              - C{token}:  If specified, card associated with card token will be used. 
+              - C{token}:  If specified, card associated with card token will be used. [max length: 255] 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
           @param private_api_key: Private key to use for the API call. If C{None}, the value of C{simplify.private_key} will be used.
@@ -1316,8 +1321,8 @@ class Payment(Domain):
           Retrieve Payment objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{dateCreated} C{amount} C{id} C{description} C{paymentDate}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1348,10 +1353,10 @@ class Plan(Domain):
         """
           Creates an Plan object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of payment for the plan in minor units. Example: 1000 = 10.00 B{required }
-              - C{currency}:  Currency code (ISO-4217) for the plan. Must match the currency associated with your account. B{required }B{default:USD}
+              - C{amount}:  Amount of payment for the plan in minor units. Example: 1000 = 10.00 [min value: 50, max value: 99999999] B{required }
+              - C{currency}:  Currency code (ISO-4217) for the plan. Must match the currency associated with your account. [default: USD] B{required }
               - C{frequency}:  Frequency of payment for the plan. Example: Monthly B{required }
-              - C{name}:  Name of the plan B{required }
+              - C{name}:  Name of the plan [max length: 50, min length: 2] B{required }
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
           @param private_api_key: Private key to use for the API call. If C{None}, the value of C{simplify.private_key} will be used.
@@ -1373,8 +1378,8 @@ class Plan(Domain):
           Retrieve Plan objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{dateCreated} C{amount} C{frequency} C{name} C{id}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1399,7 +1404,7 @@ class Plan(Domain):
           Updates this object
 
           The properties that can be updated:  
-            - C{name} Name of the plan. B{(required)}
+            - C{name} Name of the plan. [min length: 2] B{(required)}
 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1418,7 +1423,7 @@ class Refund(Domain):
         """
           Creates an Refund object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of the refund in minor units. Example: 1000 = 10.00 B{required }
+              - C{amount}:  Amount of the refund in minor units. Example: 1000 = 10.00 [min value: 1, max value: 99999999] B{required }
               - C{payment}:  ID of the payment for the refund B{required }
               - C{reason}:  Reason for the refund 
               - C{reference}:  Custom reference field to be used with outside systems. 
@@ -1435,8 +1440,8 @@ class Refund(Domain):
           Retrieve Refund objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{id} C{amount} C{description} C{dateCreated} C{paymentDate}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1467,14 +1472,14 @@ class Subscription(Domain):
         """
           Creates an Subscription object
           @param params: a dict of parameters; valid keys are:
-              - C{amount}:  Amount of the payment (minor units). Example: 1000 = 10.00 
+              - C{amount}:  Amount of the payment (minor units). Example: 1000 = 10.00 [min value: 50, max value: 99999999] 
               - C{coupon}:  Coupon ID associated with the subscription 
-              - C{currency}:  Currency code (ISO-4217). Must match the currency associated with your account. B{default:USD}
+              - C{currency}:  Currency code (ISO-4217). Must match the currency associated with your account. [default: USD] 
               - C{customer}:  Customer that is enrolling in the subscription. 
               - C{frequency}:  Frequency of payment for the plan. Example: Monthly 
               - C{name}:  Name describing subscription 
               - C{plan}:  The ID of the plan that should be used for the subscription. 
-              - C{quantity}:  Quantity of the plan for the subscription. 
+              - C{quantity}:  Quantity of the plan for the subscription. [min value: 1] 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
           @param private_api_key: Private key to use for the API call. If C{None}, the value of C{simplify.private_key} will be used.
@@ -1496,8 +1501,8 @@ class Subscription(Domain):
           Retrieve Subscription objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{id} C{plan}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1522,11 +1527,11 @@ class Subscription(Domain):
           Updates this object
 
           The properties that can be updated:  
-            - C{amount} Amount of the payment (minor units). Example: 1000 = 10.00 
+            - C{amount} Amount of the payment (minor units). Example: 1000 = 10.00 [min value: 50, max value: 99999999] 
 
             - C{coupon} Coupon being assigned to this subscription 
 
-            - C{currency} Currency code (ISO-4217). Must match the currency associated with your account. 
+            - C{currency} Currency code (ISO-4217). Must match the currency associated with your account. [default: USD] 
 
             - C{frequency} Frequency of payment for the plan. Example: Monthly 
 
@@ -1534,9 +1539,9 @@ class Subscription(Domain):
 
             - C{plan} Plan that should be used for the subscription. 
 
-            - C{prorate} Whether to prorate existing subscription. B{(required)}
+            - C{prorate} Whether to prorate existing subscription. [default: true] B{(required)}
 
-            - C{quantity} Quantity of the plan for the subscription. 
+            - C{quantity} Quantity of the plan for the subscription. [min value: 1] 
 
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
@@ -1577,8 +1582,8 @@ class Webhook(Domain):
           Retrieve Webhook objects.
           @param criteria: a dict of parameters; valid keys are:
                - C{filter}  Filters to apply to the list. 
-               - C{max}  Allows up to a max of 50 list items to return. B{default:20}
-               - C{offset}  Used in paging of the list.  This is the start offset of the page. B{default:0}
+               - C{max}  Allows up to a max of 50 list items to return. [max value: 50, default: 20] 
+               - C{offset}  Used in paging of the list.  This is the start offset of the page. [default: 0] 
                - C{sorting}  Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either C{asc} for ascending or C{desc} for descending).  Sortable properties are:  C{dateCreated}.
           @param auth_args: an Authentication object used for the API call.  If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used.
               For backwards compatibility the public and private keys may be passed instead of an Authentication object.
